import {Component} from "@angular/core";
import {HotelComponent} from "./hotel.component";
import {Hotel} from "./hotel";
import {FormsModule} from "@angular/forms";

@Component({
  standalone: true,
  template: `
    <form>
      <input name="search" [ngModel]="search" (ngModelChange)="searchEvent($event)">
    </form>
    @for (hotel of matchingHotels; track hotel.hotelId) {
        <app-hotel [hotel]="hotel"></app-hotel>
        <hr>
    } @empty {
      <h1>no matching results for {{search}}</h1>
    }
  `,
  imports: [FormsModule, HotelComponent],
  selector: 'app-hotels'
})
export class HotelsComponent {
  public search: string = '';

  public matchingHotels: Hotel[] = [];

  constructor() {
    this.matchingHotels = this.hotels;
  }

  public searchEvent(input: string) {
    this.search = input.toLowerCase();
    this.matchingHotels = []
    this.hotels.forEach((hotel: Hotel) => {
      if (hotel.hotelName.toLowerCase().includes(this.search)) {
          this.matchingHotels.push(hotel);
      }
    })
  }

  public hotels: Hotel[] = [
    {
      "hotelId": 1,
      "hotelName": "Buea süßes Leben",
      "description": "Schöne Aussicht am Meer",
      "price": 230.5,
      "imageUrl": "assets/img/heisenberg.jpg",
      "rating": 3.5
    },
    {
      "hotelId": 2,
      "hotelName": "Marrakesch",
      "description": "Genießen Sie den Blick auf die Berge",
      "price": 145.5,
      "imageUrl": "assets/img/kjan.png",
      "rating": 5
    },
    {
      "hotelId": 3,
      "hotelName": "Abuja neuer Palast",
      "description": "Kompletter Aufenthalt mit Autoservice",
      "price": 120.12,
      "imageUrl": "assets/img/huy.png",
      "rating": 4
    },
    {
      "hotelId": 4,
      "hotelName": "OUR Hotel",
      "description": "Wunderschönes Ambiente für Ihren Aufenthalt",
      "price": 135.12,
      "imageUrl": "assets/img/rat.png",
      "rating": 2.5
    }
  ]
}
